#!/usr/bin/env python3

import click
from pypelinez.feature import feature
from pypelinez.apple import apple


@click.group()
def main():
    pass


main.add_command(feature)
main.add_command(apple)

if __name__ == "__main__":
    main()



import click
import pypelines.utilities as utilities


def git_branch_name():
    """Current git branch name

    Returns:
    str:Returning current git branch name

    """

    result = utilities.action("git rev-parse --abbrev-ref HEAD")
    utilities.assert_result(result)
    return utilities.transform_result(result)


# -------------------------- commands

# group
@click.group()
def feature():
    pass


# name
@feature.command()
def name():
    print(git_branch_name())


# start
@feature.command()
@click.argument("name")
def start(name):
    """Creates a new branch with the format feature/<name>


    Parameters:
    name (str): feature branch name

    """

    result = utilities.action("git checkout -b feature/" + name)
    utilities.print_result(result)
    utilities.assert_result(result)


# commit
@feature.command()
def add_commit():
    result = utilities.action("git add -A")
    utilities.print_result(result)
    utilities.assert_result(result)

    result = utilities.action("git commit -F COMMIT.md")
    utilities.print_result(result)
    utilities.assert_result(result)


# finish
@feature.command()
def finish():
    branch = git_branch_name()

    result = utilities.action("git checkout main")
    utilities.print_result(result)
    utilities.assert_result(result)

    result = utilities.action("git merge --squash " + branch)
    utilities.print_result(result)
    utilities.assert_result(result)

    result = utilities.action("git branch -D " + branch)
    utilities.print_result(result)
    utilities.assert_result(result)

    result = utilities.action("git pull origin main")
    utilities.print_result(result)
    utilities.assert_result(result)


# merge request
# https://docs.gitlab.com/ee/user/project/merge_requests/merge_when_pipeline_succeeds.html
@feature.command()
def merge_request():
    feature_branch = git_branch_name()
    merge_request_file = open("MERGE_REQUEST.md", "r")
    merge_description = merge_request_file.read()
    merge_request_file.close()

    request = """\
    git push \\
    -o merge_request.create \\
    -o merge_request.target=main \\
    -o merge_request.merge_when_pipeline_succeeds \\
    -o merge_request.remove_source_branch \\
    -o merge_request.title=\"Merge request for {branch}\" \\
    -o merge_request.description=\"{description}\" \\
    origin {branch}
  """.format(
        branch=feature_branch, description=merge_description
    )

    result = utilities.action(request)
    utilities.print_result(result)
    utilities.assert_result(result)



import os
import subprocess
import sys
import shutil

current = os.getcwd()

# -------------------------- utilities


def action(command, cwd=current):
    return subprocess.run(command, cwd=cwd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)


def assert_result(result):
    if result.returncode != 0:
        sys.exit(result.returncode)


def transform_result(result):
    # https://stackoverflow.com/questions/41918836/how-do-i-get-rid-of-the-b-prefix-in-a-string-in-python
    return (result.stdout.decode("UTF-8") + result.stderr.decode("UTF-8")).strip()


def print_result(result):
    print(transform_result(result))


def remove_directory(directory):
    shutil.rmtree(directory)
